from git import Repo


class GitUtils:

    ## commit d'un fichier (branche principale)
    # @param cheminFichier le chemin du fichier
    # @param texteCommit le texte associé au commit
    # @return le hash du commit
    def commit(self, cheminFichier, nomFichier, texteCommit):
        repo = Repo.init(cheminFichier)

        # # Il faudra faire une extraction du nom du fichier a partir du chemin
        repo.index.add([nomFichier])
        repo.index.commit(texteCommit)

        return repo.head.object.hexsha

    ## commit d'un fichier (branche principale)
    # @param cheminFichier le chemin du fichier
    # @param texteCommit le texte associé au commit
    # @return le hash du commit
    def embranchement(self, cheminFichier, nomBranche):
        repo = Repo.init(cheminFichier)
        repo.create_head(nomBranche, 'HEAD')

    ## changer la version actuelle (avec une base commit):
    # @param chemin chemin du repertoire git
    # @param commit branche contenant le commit de la version à charger
    def changerVersionCommit(self, chemin, commit):
        repo = Repo.init(chemin)
        repo.head.reference = repo.commit(commit)
        repo.head.reset(index=True, working_tree=True)
        # repo.git.checkout("c785462dfd454045798baedb11d1674837733962")

    ## changer la version actuelle (avec une base branche):
    # @param chemin chemin du repertoire git
    # @param nombranche branche contenant la branche avec le contenu désiré
    def changerVersionBranche(self, chemin, branche):
        repo = Repo.init(chemin)
        repo.git.checkout(branche)
        repo.head.reset(index=True, working_tree=True)

    ## valider une nouvelle version courante d'un contenu - Un peu plus compliqué à faire.
    # @param chemin chemin du repertoire git
    # @param nombranche branche contenant le contenu temporaire à repasser en principal
    def mergeVersion(self, chemin, nombranche):
        # "objectif : fusionner main et en_cours"
        repo = Repo.init(chemin)
        master = repo.branches['master']
        enCours = repo.branches[nombranche]
        # merge des deux branches
        base = repo.merge_base(enCours, master)
        repo.index.merge_tree(master, base=base)

        # on commit le merge
        repo.index.commit('Mise à jour de la branche principale',
                          parent_commits=(enCours.commit, master.commit))

        return repo.head.object.hexsha
